==> bangumi-data-0.3.55.tgz: package/README.md <==
# Bangumi Data [![Awesome](https://badgen.net/badge/icon/awesome/fc60a8?icon=awesome&label)](https://github.com/bangumi-data/awesome)

[![Build Status](https://badgen.net/travis/bangumi-data/bangumi-data?icon=travis&label=build)](https://travis-ci.org/bangumi-data/bangumi-data)
[![NPM Version](https://badgen.net/npm/v/bangumi-data?icon=npm)](https://www.npmjs.com/package/bangumi-data)
[![File size](https://badgen.net/bundlephobia/minzip/bangumi-data?icon=https://api.iconify.design/ant-design:file-zip-outline.svg?color=white)](https://bundlephobia.com/result?p=bangumi-data)
[![jsDelivr](https://badgen.net/jsdelivr/hits/npm/bangumi-data?icon=https://api.iconify.design/simple-icons:jsdelivr.svg?color=white)](https://www.jsdelivr.com/package/npm/bangumi-data)
[![License](https://badgen.net/npm/license/bangumi-data?icon=https://api.iconify.design/octicon:law.svg?color=white)](https://github.com/bangumi-data/bangumi-data#license)
[![Slack Welcome](https://badgen.net/badge/icon/welcome?icon=slack&label=slack)](https://bangumi-data.slack.com)
[![PRs Welcome](https://badgen.net/badge/PRs/welcome?icon=https://api.iconify.design/octicon:git-pull-request.svg?color=white)](CONTRIBUTING.md)

动画番组及其放送、资讯站点数据集合

## 使用方法

```bash
npm install bangumi-data
```

```js
const bangumiData = require('bangumi-data');
```

也可通过 CDN `https://cdn.jsdelivr.net/npm/bangumi-data@0.3/dist/data.json` 获取 `v0.3.x` 的最新数据

## 哪些项目在使用

https://github.com/bangumi-data/awesome

## 帮助我们改进

见 [CONTRIBUTING.md](CONTRIBUTING.md)

## License

The data in this repo is available for use under a CC BY 4.0 license (http://creativecommons.org/licenses/by/4.0/). For attribution just mention somewhere that the source is bangumi-data. If you have any questions about using the data for your project please contact us.

==> bangumi-data-0.3.125.tgz: package/README.md <==
# Bangumi Data [![Awesome](https://badgen.net/badge/icon/awesome/fc60a8?icon=awesome&label)](https://github.com/bangumi-data/awesome)

[![Build Status](https://badgen.net/travis/bangumi-data/bangumi-data?icon=travis&label=build)](https://travis-ci.org/bangumi-data/bangumi-data)
[![NPM Version](https://badgen.net/npm/v/bangumi-data?icon=npm)](https://www.npmjs.com/package/bangumi-data)
[![File size](https://badgen.net/bundlephobia/minzip/bangumi-data?icon=https://api.iconify.design/ant-design:file-zip-outline.svg?color=white)](https://bundlephobia.com/result?p=bangumi-data)
[![jsDelivr](https://badgen.net/jsdelivr/hits/npm/bangumi-data?icon=https://api.iconify.design/simple-icons:jsdelivr.svg?color=white)](https://www.jsdelivr.com/package/npm/bangumi-data)
[![License](https://badgen.net/npm/license/bangumi-data?icon=https://api.iconify.design/octicon:law.svg?color=white)](https://github.com/bangumi-data/bangumi-data#license)
[![Slack Welcome](https://badgen.net/badge/icon/welcome?icon=slack&label=slack)](https://bangumi-data.slack.com)
[![PRs Welcome](https://badgen.net/badge/PRs/welcome?icon=https://api.iconify.design/octicon:git-pull-request.svg?color=white)](CONTRIBUTING.md)

动画番组及其放送、资讯站点数据集合

## 使用方法

```bash
npm install bangumi-data
```

```js
const bangumiData = require('bangumi-data');
```

也可通过 CDN `https://unpkg.com/bangumi-data@0.3/dist/data.json` 获取 `v0.3.x` 的最新数据

## 哪些项目在使用

https://github.com/bangumi-data/awesome

## 帮助我们改进

见 [CONTRIBUTING.md](CONTRIBUTING.md)

## License

The data in this repo is available for use under a CC BY 4.0 license (http://creativecommons.org/licenses/by/4.0/). For attribution just mention somewhere that the source is bangumi-data. If you have any questions about using the data for your project please contact us.
